![T3CO Logo](t3co_logo.svg)

# **T3CO** : Transportation Technology Total Cost of Ownership Tool

## Description

This repo houses T3CO (Transportation Technology Total Cost of Ownership), software for modeling total cost of ownership for commercial vehicles with advanced powertrains.

To learn about the models, go to the [Overview](./T3CO_Overview.md)

To get started with the tool, go to the [Installation Guide](./installation.md)

To run your first analysis after installing T3CO, go to the [Quick Start Guide](./quick_start.md)

## Usage
**T3CO** is a general framework allowing a user to determine the total cost of ownership (TCO) of a FASTSim vehicle (paired with a FASTSim DriveCycle(s) for determining fuel efficiency). The user can also determine performance of gradability, acceleration, and range. In addition to straight TCO computation there is also the option to optimize a vehicle powertrain such that it meets performance optional targets while also optionally minimizing TCO.

